@@ -1,13 +1,14 @@
 /***************************************************************************
  $RCSfile$
  -------------------
- cvs         : $Id: bankinfoplugin_be.h 698 2005-11-30 13:52:48Z cstim $
+ cvs         : $Id$
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
 
  ***************************************************************************
- *          Please see toplevel file COPYING for license details           *
+ * This file is part of the project "AqBanking".                           *
+ * Please see toplevel file COPYING of that project for license details.   *
  ***************************************************************************/
 
 
@@ -127,6 +128,29 @@ void AB_BankInfoPlugin_SetCheckAccountFn(AB_BANKINFO_PLUGIN *bip,
 /*@}*/
 
 
+
+typedef AB_BANKINFO_PLUGIN* (*AB_PLUGIN_BANKINFO_FACTORY_FN)(GWEN_PLUGIN *pl,
+							     AB_BANKING *ab,
+							     GWEN_DB_NODE *db);
+
+
+AQBANKING_API
+GWEN_PLUGIN *AB_Plugin_BankInfo_new(GWEN_PLUGIN_MANAGER *pm,
+				    const char *name,
+				    const char *fileName);
+
+
+AQBANKING_API
+AB_BANKINFO_PLUGIN *AB_Plugin_BankInfo_Factory(GWEN_PLUGIN *pl,
+					       AB_BANKING *ab,
+					       GWEN_DB_NODE *db);
+
+AQBANKING_API
+void AB_Plugin_BankInfo_SetFactoryFn(GWEN_PLUGIN *pl,
+				     AB_PLUGIN_BANKINFO_FACTORY_FN fn);
+
+
+
 #endif /* AQBANKING_BANKINFOPLUGIN_BE_H */
 
 
