@@ -349,14 +349,16 @@ AH_JOB *AH_Job_SendKeys_new(AB_USER *u,
     return 0;
   }
 
-  dbKey=GWEN_DB_GetGroup(AH_Job_GetArguments(j),
-			 GWEN_DB_FLAGS_DEFAULT,
-			 "authKey");
-  assert(dbKey);
-  if (AH_Job_SendKeys_PrepareKey(j, dbKey, authKeyInfo, 2)) {
-    DBG_ERROR(AQHBCI_LOGDOMAIN, "Could not prepare authkey");
-    AH_Job_free(j);
-    return 0;
+  if (authKeyInfo) {
+    dbKey=GWEN_DB_GetGroup(AH_Job_GetArguments(j),
+			   GWEN_DB_FLAGS_DEFAULT,
+			   "authKey");
+    assert(dbKey);
+    if (AH_Job_SendKeys_PrepareKey(j, dbKey, authKeyInfo, 2)) {
+      DBG_ERROR(AQHBCI_LOGDOMAIN, "Could not prepare authkey");
+      AH_Job_free(j);
+      return 0;
+    }
   }
 
   DBG_INFO(AQHBCI_LOGDOMAIN, "JobSendKeys created");
@@ -736,6 +738,7 @@ int AH_Job_GetSysId_ExtractSysId(AH_JOB *j){
 }
 
 
+
 int AH_Job_GetSysId_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx,
 			    uint32_t guiid){
   AH_JOB_GETSYSID *jd;
@@ -772,6 +775,10 @@ int AH_Job_GetSysId_NextMsg(AH_JOB *j) {
     DBG_INFO(AQHBCI_LOGDOMAIN, "Could not extract system id");
     return 0;
   }
+  else {
+    DBG_INFO(AQHBCI_LOGDOMAIN, "Setting system id [%s]", jd->sysId);
+    AH_User_SetSystemId(AH_Job_GetUser(j), jd->sysId);
+  }
 
   return 1;
 }
