@@ -194,11 +194,11 @@ int AH_Msg_SignRdh(AH_MSG *hmsg,
     return GWEN_ERROR_NOT_FOUND;
   }
 
-  node=GWEN_MsgEngine_FindNodeByProperty(e,
-                                         "SEG",
-                                         "id",
-                                         0,
-                                         "SigHead");
+  node=GWEN_MsgEngine_FindNodeByPropertyStrictProto(e,
+						    "SEG",
+						    "id",
+						    0,
+						    "SigHead");
   if (!node) {
     DBG_INFO(AQHBCI_LOGDOMAIN, "Segment \"SigHead\" not found");
     return GWEN_ERROR_INTERNAL;
@@ -230,15 +230,21 @@ int AH_Msg_SignRdh(AH_MSG *hmsg,
   }
 
   /* store system id */
-  p=AH_User_GetSystemId(su);
-  if (p==NULL)
-    p=GWEN_Crypt_Token_Context_GetSystemId(ctx);
-  if (p)
-    GWEN_DB_SetCharValue(cfg, GWEN_DB_FLAGS_DEFAULT,
-			 "SecDetails/SecId", p);
-  else {
+  if (hmsg->noSysId) {
     GWEN_DB_SetCharValue(cfg, GWEN_DB_FLAGS_DEFAULT,
 			 "SecDetails/SecId", "0");
+  }
+  else {
+    p=AH_User_GetSystemId(su);
+    if (p==NULL)
+      p=GWEN_Crypt_Token_Context_GetSystemId(ctx);
+    if (p)
+      GWEN_DB_SetCharValue(cfg, GWEN_DB_FLAGS_DEFAULT,
+			   "SecDetails/SecId", p);
+    else {
+      GWEN_DB_SetCharValue(cfg, GWEN_DB_FLAGS_DEFAULT,
+			   "SecDetails/SecId", "0");
+    }
 #if 0
     DBG_ERROR(AQHBCI_LOGDOMAIN,
 	      "No system id on RDH medium, should not happen (%d)", rv);
@@ -353,11 +359,11 @@ int AH_Msg_SignRdh(AH_MSG *hmsg,
 		       "ctrlref", ctrlref);
 
   /* get node */
-  node=GWEN_MsgEngine_FindNodeByProperty(e,
-                                         "SEG",
-                                         "id",
-                                         0,
-                                         "SigTail");
+  node=GWEN_MsgEngine_FindNodeByPropertyStrictProto(e,
+						    "SEG",
+						    "id",
+						    0,
+						    "SigTail");
   if (!node) {
     DBG_INFO(AQHBCI_LOGDOMAIN, "Segment \"SigTail\"not found");
     GWEN_Buffer_free(hbuf);
@@ -545,11 +551,11 @@ int AH_Msg_EncryptRdh(AH_MSG *hmsg) {
   GWEN_Crypt_Key_free(sk);
 
   /* create crypt head */
-  node=GWEN_MsgEngine_FindNodeByProperty(e,
-                                         "SEG",
-                                         "id",
-                                         0,
-                                         "CryptHead");
+  node=GWEN_MsgEngine_FindNodeByPropertyStrictProto(e,
+						    "SEG",
+						    "id",
+						    0,
+						    "CryptHead");
   if (!node) {
     DBG_INFO(AQHBCI_LOGDOMAIN, "Segment \"CryptHead\" not found");
     GWEN_Buffer_free(mbuf);
@@ -571,24 +577,30 @@ int AH_Msg_EncryptRdh(AH_MSG *hmsg) {
   }
 
   /* store system id */
-  p=AH_User_GetSystemId(u);
-  if (p==NULL)
-    p=GWEN_Crypt_Token_Context_GetSystemId(ctx);
-  if (p)
-    GWEN_DB_SetCharValue(cfg, GWEN_DB_FLAGS_DEFAULT,
-			 "SecDetails/SecId", p);
-  else {
-    DBG_INFO(AQHBCI_LOGDOMAIN,
-	     "No System id on RDH medium, using default");
+  if (hmsg->noSysId) {
     GWEN_DB_SetCharValue(cfg, GWEN_DB_FLAGS_DEFAULT,
 			 "SecDetails/SecId", "0");
+  }
+  else {
+    p=AH_User_GetSystemId(u);
+    if (p==NULL)
+      p=GWEN_Crypt_Token_Context_GetSystemId(ctx);
+    if (p)
+      GWEN_DB_SetCharValue(cfg, GWEN_DB_FLAGS_DEFAULT,
+			   "SecDetails/SecId", p);
+    else {
+      DBG_INFO(AQHBCI_LOGDOMAIN,
+	       "No System id on RDH medium, using default");
+      GWEN_DB_SetCharValue(cfg, GWEN_DB_FLAGS_DEFAULT,
+			   "SecDetails/SecId", "0");
 #if 0
-    DBG_ERROR(AQHBCI_LOGDOMAIN,
-	      "No system id on RDH medium, should not happen (%d)", rv);
-    GWEN_DB_Group_free(cfg);
-    GWEN_Buffer_free(mbuf);
-    return GWEN_ERROR_INTERNAL;
+      DBG_ERROR(AQHBCI_LOGDOMAIN,
+		"No system id on RDH medium, should not happen (%d)", rv);
+      GWEN_DB_Group_free(cfg);
+      GWEN_Buffer_free(mbuf);
+      return GWEN_ERROR_INTERNAL;
 #endif
+    }
   }
 
   /* store encrypted message key */
@@ -621,11 +633,11 @@ int AH_Msg_EncryptRdh(AH_MSG *hmsg) {
                       GWEN_Buffer_GetUsedBytes(mbuf));
   GWEN_Buffer_free(mbuf);
 
-  node=GWEN_MsgEngine_FindNodeByProperty(e,
-                                         "SEG",
-                                         "id",
-                                         0,
-                                         "CryptData");
+  node=GWEN_MsgEngine_FindNodeByPropertyStrictProto(e,
+						    "SEG",
+						    "id",
+						    0,
+						    "CryptData");
   if (!node) {
     DBG_INFO(AQHBCI_LOGDOMAIN, "Segment \"CryptData\"not found");
     GWEN_Buffer_free(hbuf);
