@@ -1,7 +1,4 @@
 /***************************************************************************
- $RCSfile$
-                             -------------------
-    cvs         : $Id: de_p.h 276 2005-04-13 22:18:59Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -31,15 +28,24 @@ struct AB_BANKINFO_PLUGIN_DE {
   GWEN_DB_NODE *dbData;
 };
 
+static
+void GWENHYWFAR_CB AB_BankInfoPluginDE_FreeData(void *bp, void *p);
 
-void AB_BankInfoPluginDE_FreeData(void *bp, void *p);
+static
+AB_BANKINFO_PLUGIN *AB_Plugin_BankInfoDE_Factory(GWEN_PLUGIN *pl, AB_BANKING *ab, GWEN_DB_NODE *db);
 
-AB_BANKINFO_CHECKRESULT
+
+static AB_BANKINFO_CHECKRESULT
 AB_BankInfoPluginDE_CheckAccount(AB_BANKINFO_PLUGIN *bip,
                                  const char *branchId,
                                  const char *bankId,
                                  const char *accountId);
 
+AQBANKING_EXPORT
+GWEN_PLUGIN *bankinfo_de_factory(GWEN_PLUGIN_MANAGER *pm,
+				 const char *name,
+				 const char *fileName);
+
 #endif /* AQBANKING_BANKINFO_DE_P_H */
 
 
