@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: generic_l.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: generic_l.h,v 1.1 2005/04/13 22:18:58 aquamaniac Exp $
+    cvs         : $Id$
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
